translate.misc.ini.INISection

Package translate :: Package misc :: Module ini :: Class INISection |
[hide private]
[frames] | no frames]

# Class INISection

source code

Instance Methods | [hide private]
__init__(self, lineobj, defaults=None, optionxformvalue=None, optionxformsource=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__getitem__(self, key) | source code
__setitem__(self, key, value) | source code
__delitem__(self, key) | source code
__iter__(self) | source code
new_namespace(self, name) | source code
Inherited from `iniparse.config.ConfigNamespace`: `__delattr__`, `__getattr__`, `__getstate__`, `__setattr__`, `__setstate__` Inherited from `iniparse.config.ConfigNamespace` (private): `_new_namespace` Inherited from `object`: `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _lines = `None` hash(x)
| _options = `None` hash(x)
| _defaults = `None` hash(x)
| _optionxformvalue = `None` hash(x)
| _optionxformsource = `None` hash(x)

Properties | [hide private]
| _optionxform
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, lineobj, defaults=None, optionxformvalue=None, optionxformsource=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __getitem__(self, key) (Indexing operator) | source code
Overrides: iniparse.config.ConfigNamespace.__getitem__

### __setitem__(self, key, value) (Index assignment operator) | source code
Overrides: iniparse.config.ConfigNamespace.__setitem__

### __delitem__(self, key) (Index deletion operator) | source code
Overrides: iniparse.config.ConfigNamespace.__delitem__

### __iter__(self) | source code
Overrides: iniparse.config.ConfigNamespace.__iter__

Property Details | [hide private]

### _optionxform Get Method: unreachable.getfn(self) Set Method: unreachable.setfn(self, value)